@@ -29,15 +29,23 @@ from gi.repository import GLib
 
 from gajim import dialogs
 from gajim.common import app
-from gajim.common.connection_handlers_events import (
-    MessageNotSentEvent, MessageReceivedEvent, MamMessageReceivedEvent)
+from gajim.common.connection_handlers_events import MessageNotSentEvent
 from gajim.plugins import GajimPlugin
 
 log = logging.getLogger('gajim.plugin_system.oldpgp')
 
 ERROR_MSG = ''
-if not app.HAVE_GPG:
-    ERROR_MSG = 'Please install python-gnupg'
+if hasattr(app, 'HAVE_GPG'):
+    # Gajim 1.0.0
+    HAVE_GPG = app.HAVE_GPG
+else:
+    # Gajim 1.0.3+
+    HAVE_GPG = app.is_installed('GPG')
+if not HAVE_GPG:
+    if os.name == 'nt':
+        ERROR_MSG = _('Please install GnuPG / Gpg4win')
+    else:
+        ERROR_MSG = _('Please install python-gnupg and PGP')
 
 ALLOWED_TAGS = [('request', nbxmpp.NS_RECEIPTS),
                 ('active', nbxmpp.NS_CHATSTATES),
@@ -57,12 +65,14 @@ ALLOWED_TAGS = [('request', nbxmpp.NS_RECEIPTS),
 class OldPGPPlugin(GajimPlugin):
 
     def init(self):
+        self.description = _('PGP encryption as per XEP-0027')
         if ERROR_MSG:
             self.activatable = False
             self.available_text = ERROR_MSG
             return
         self.config_dialog = None
         self.encryption_name = 'PGP'
+        self.allow_zeroconf = True
         self.gui_extension_points = {
             'encrypt' + self.encryption_name: (self._encrypt_message, None),
             'decrypt': (self._message_received, None),
@@ -136,10 +146,15 @@ class OldPGPPlugin(GajimPlugin):
             # Another Plugin already decrypted the message
             return
         account = conn.name
-        if isinstance(obj, MessageReceivedEvent):
+        if obj.name == 'message-received':
             enc_tag = obj.stanza.getTag('x', namespace=nbxmpp.NS_ENCRYPTED)
-        elif isinstance(obj, MamMessageReceivedEvent):
-            enc_tag = obj.msg_.getTag('x', namespace=nbxmpp.NS_ENCRYPTED)
+        elif obj.name == 'mam-message-received':
+            # Compatibility for Gajim 1.0.3
+            if hasattr(obj, 'message'):
+                message = obj.message
+            else:
+                message = obj.msg_
+            enc_tag = message.getTag('x', namespace=nbxmpp.NS_ENCRYPTED)
         else:
             return
         if enc_tag:
